@@ -9,8 +9,7 @@ import random
 import sys
 import types
 import warnings
-
-# from collections import OrderedDict, defaultdict
+from datetime import datetime
 
 logger = logging.getLogger("stressor")
 
@@ -88,8 +87,10 @@ class PathStack:
     def pop(self):
         return self.stack.pop()
 
-    def get_path(self, last_seg=None):
+    def get_path(self, skip_segs=0, last_seg=None):
         stack = [str(s) for s in self.stack if s is not _VOID_SEGMENT]
+        if skip_segs > 0:
+            stack = stack[skip_segs:]
         if last_seg is not None:
             stack = stack[:-1]
             stack.append(last_seg)
@@ -466,6 +467,26 @@ def get_random_number(num_or_tuple):
     return v
 
 
+def datetime_to_iso(dt=None, microseconds=False):
+    """Return current UTC datetime as ISO formatted string."""
+    if dt is None:
+        dt = datetime.now()
+    if not microseconds:
+        dt.replace(microsecond=0)
+    return dt.isoformat(sep=" ")
+
+
+def iso_to_datetime(iso):
+    """Convert as ISO formatted datetime string to datetime."""
+    dt = datetime.strptime(iso, "%Y-%m-%dT%H:%M:%S.%fZ")
+    return dt
+
+
+def iso_to_stamp(iso):
+    """Convert as ISO formatted datetime string to datetime."""
+    return iso_to_datetime(iso).timestamp()
+
+
 def format_elap(seconds, count=None, unit="items", high_prec=False):
     """Return elapsed time as H:M:S.h string with reasonable precision."""
     days, seconds = divmod(seconds, 86400) if seconds else (0, 0)
@@ -501,6 +522,23 @@ def format_elap(seconds, count=None, unit="items", high_prec=False):
     return res
 
 
+def format_rate(count, time, unit=None, high_prec=False):
+    """Return count / time with reasonable precision."""
+    if not time or not count:
+        return "0"
+
+    rate = float(count) / float(time)
+    if rate >= 1000:
+        res = "{}".format(int(round(rate)))
+    elif rate >= 100:
+        res = "{}".format(round(rate, 1))
+    elif rate >= 10:
+        res = "{}".format(round(rate, 2))
+    else:
+        res = "{}".format(round(rate, 3))
+    return res
+
+
 # def format_relative_datetime(dt, as_html=False):
 #     """Format a datetime object as relative expression (i.e. '3 minutes ago')."""
 #     try:
@@ -621,26 +659,26 @@ def format_elap(seconds, count=None, unit="items", high_prec=False):
 #     return "%s%s%s" % (snum, magsuffix, bytesuffix)
 
 
-# def lstrip_string(s, prefix, ignore_case=False):
-#     """Remove leading string from s.
+def lstrip_string(s, prefix, ignore_case=False):
+    """Remove leading string from s.
 
-#     Note: This is different than `s.lstrip('bar')` which would remove
-#     leading 'b', 'a', and 'r' chars.
-#     """
-#     if ignore_case:
-#         if s.lower().startswith(prefix.lower()):
-#             return s[len(prefix):]
-#     else:
-#         if s.startswith(prefix):
-#             return s[len(prefix):]
-#     return s
+    Note: This is different than `s.lstrip('bar')` which would remove
+    all leading 'a', 'b', and 'r' chars.
+    """
+    if ignore_case:
+        if s.lower().startswith(prefix.lower()):
+            return s[len(prefix) :]
+    else:
+        if s.startswith(prefix):
+            return s[len(prefix) :]
+    return s
 
 
 # def rstrip_string(s, suffix, ignore_case=False):
 #     """Remove trailing string from s.
 
 #     Note: This is different than `s.rstrip('bar')` which would remove
-#     trailing 'b', 'a', and 'r' chars.
+#     all trailing 'a', 'b', and 'r' chars.
 #     """
 #     if ignore_case:
 #         if s.lower().endswith(suffix.lower()):
